aboutsummaryrefslogtreecommitdiffstats
path: root/ui/qt/simple_statistics_dialog.h
diff options
context:
space:
mode:
authorGuy Harris <guy@alum.mit.edu>2015-12-28 16:31:06 -0800
committerGuy Harris <guy@alum.mit.edu>2015-12-29 00:31:37 +0000
commit9067ee8f5a9d986efdc2fb7da9cd8f39017af129 (patch)
tree8a962e93c3904ef417ae8e5183e814d9d733fbf1 /ui/qt/simple_statistics_dialog.h
parent0c156fec93e31a8d80653e0288925acf2275111e (diff)
Rename new_stat_tap_ui to stat_tap_table_ui.
A "new" statistics tap UI is a statistics tap UI where the statistics are maintained as tables and common code handles the tables; what matters is the tables, not that it's "new". Change-Id: I7a0e63cfac98c24cd5e7dce973b9a0cc5b6a03ba Reviewed-on: https://code.wireshark.org/review/12897 Reviewed-by: Guy Harris <guy@alum.mit.edu>
Diffstat (limited to 'ui/qt/simple_statistics_dialog.h')
-rw-r--r--ui/qt/simple_statistics_dialog.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/ui/qt/simple_statistics_dialog.h b/ui/qt/simple_statistics_dialog.h
index 5513112d9e..47d1388514 100644
--- a/ui/qt/simple_statistics_dialog.h
+++ b/ui/qt/simple_statistics_dialog.h
@@ -31,7 +31,7 @@ class SimpleStatisticsDialog : public TapParameterDialog
Q_OBJECT
public:
- SimpleStatisticsDialog(QWidget &parent, CaptureFile &cf, struct _new_stat_tap_ui *stu, const QString filter, int help_topic = 0);
+ SimpleStatisticsDialog(QWidget &parent, CaptureFile &cf, struct _stat_tap_table_ui *stu, const QString filter, int help_topic = 0);
static TapParameterDialog *createSimpleStatisticsDialog(QWidget &parent, const QString cfg_str, const QString filter, CaptureFile &cf);
protected:
@@ -43,7 +43,7 @@ protected:
void addMissingRows(struct _new_stat_data_t *stat_data);
private:
- struct _new_stat_tap_ui *stu_;
+ struct _stat_tap_table_ui *stu_;
// Callbacks for register_tap_listener
static void tapReset(void *sd_ptr);
@@ -56,7 +56,7 @@ private slots:
/** Register function to register dissectors that support a "simple" statistics table.
*
* @param data new_stat_tap_ui* representing dissetor stat table
*/
void register_simple_stat_tables(gpointer data, gpointer);
@@ -56,7 +56,7 @@ private slots:
/** Register function to register dissectors that support a "simple" statistics table.
*
- * @param data new_stat_tap_ui* representing dissetor stat table
+ * @param data stat_tap_table_ui* representing dissetor stat table
*/
void register_simple_stat_tables(gpointer data, gpointer);